//
//  CIView.m
//  TestCIFilter
//
//  Created by Kevin Gross on 10/8/10.
//  Copyright 2010 Kevin Gross www.art144.com. All rights reserved.
//

#import "CIView.h"
#import <Quartz/Quartz.h>
#import "TestCIFilter.h"

@implementation CIView

@synthesize image;

- (id)initWithFrame:(NSRect)frame {
    self = [super initWithFrame:frame];
    if (self) {
		// register the filter
		[TestCIFilter registerFilter];
		initialized = NO;
    }
    return self;
}

- (void)setImage:(CIImage *)newImage
{
	if(image != newImage){
		[image release];
		image = [newImage retain];
	}
	initialized = YES;
	[self setNeedsDisplay:YES];
}

- (void)drawRect:(NSRect)dirtyRect {
	if (initialized) {
		
		CGRect imageRect;
		NSRect viewBounds;
		CGFloat hScale;
		CGFloat vScale;
		CIFilter *filter;
		CIImage *filteredImage;
		CIImage *scaledImage;
		CGAffineTransform transform;
		
		// apply the TestCIFilter
		filter = [CIFilter filterWithName:	@"TestCI"
							keysAndValues:	@"inputImage", image, @"inputColor", [CIColor colorWithRed:0.1 green:0.1 blue:0.1], nil];
		filteredImage = [filter valueForKey: @"outputImage"];
				
		// uncomment this to show that the error has nothing to do with the affine transform
//		imageRect = [filteredImage extent];
//		[[[NSGraphicsContext currentContext] CIContext] drawImage:filteredImage atPoint:viewBounds.origin fromRect:imageRect];

		// create an affine transform to scale the image to fit into the view
		imageRect = [filteredImage extent];
		viewBounds = [self bounds];
		
		vScale = viewBounds.size.height/imageRect.size.height;
		hScale = viewBounds.size.width/imageRect.size.width;
		
		transform = CGAffineTransformMakeScale(hScale, vScale);
		scaledImage = [filteredImage imageByApplyingTransform:transform];

		[[[NSGraphicsContext currentContext] CIContext] drawImage:scaledImage atPoint:viewBounds.origin fromRect:viewBounds];
		
		NSLog(@"done drawing");	
		
	} else {
		NSLog(@"uninitialized... not drawing");	
	}
}

- (void)dealloc
{
	[image release];
	[super dealloc];
}


@end
